@@ -17,16 +17,16 @@ from pytz import UTC
 
 class GetRequest(Request):
     def __init__(self, url, **kwargs):
-        kwargs.setdefault("headers", dict()).setdefault(
-            "User-Agent",
-            "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0",
+        kwargs.setdefault('headers', dict()).setdefault(
+            'User-Agent',
+            'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0',
         )
         super().__init__(url, **kwargs)
 
 
 class HeadRequest(GetRequest):
     def get_method(self):
-        return "HEAD"
+        return 'HEAD'
 
 
 class DownloaderStorage(Storage):
@@ -42,7 +42,7 @@ class DownloaderStorage(Storage):
         """
         return self.url
 
-    def open(self, name, mode="rb"):
+    def open(self, name, mode='rb'):
         """
         Retrieves the specified file from storage.
         """
@@ -51,14 +51,7 @@ class DownloaderStorage(Storage):
             self.hash = hashlib.new(self.algorithm)
         return self
 
-    def chunks(self, chunk_size=None):
-        while True:
-            chunk = self.read(chunk_size)
-            yield chunk
-            if not chunk:
-                break
-
-    def read(self, length=None):
+    def read(self, length):
         chunk = self.request.read(length)
         if self.hash:
             self.hash.update(chunk)
@@ -67,7 +60,12 @@ class DownloaderStorage(Storage):
     def close(self):
         self.request.close()
         if self.hash:
-            checksum = base64.encodebytes(self.hash.digest()).decode()
+            try:
+                # python 3
+                checksum = base64.encodebytes(self.hash.digest()).decode()
+            except AttributeError:
+                # python 2
+                checksum = base64.encodestring(self.hash.digest())
             if checksum.strip() != self.checksum:
                 raise RuntimeError(
                     'Checksum {} of {} does not match: expected "{}", got "{}"'.format(
@@ -79,7 +77,7 @@ class DownloaderStorage(Storage):
         response = None
         try:
             response = urlopen(HeadRequest(self.url))
-            last_modified = response.headers["Last-Modified"]
+            last_modified = response.headers['Last-Modified']
             return datetime.fromtimestamp(parse_http_date(last_modified), UTC)
         except Exception:
             return now()
@@ -101,7 +99,7 @@ class DownloaderFinder(BaseFinder):
     """
 
     storage_class = DownloaderStorage
-    urls_attr = "staticfiles_urls"
+    urls_attr = 'staticfiles_urls'
 
     def __init__(self, app_names=None, *args, **kwargs):
         # The list of apps that are handled
@@ -110,11 +108,11 @@ class DownloaderFinder(BaseFinder):
         self.firsts = {}
         self.lists = defaultdict(list)
         # First try to load urls from settings
-        staticfiles_urls = getattr(settings, "STATICFILES_URLS", {})
+        staticfiles_urls = getattr(settings, 'STATICFILES_URLS', {})
         if staticfiles_urls:
             self._load(
                 staticfiles_urls,
-                "settings.STATICFILES_URLS",
+                'settings.STATICFILES_URLS',
             )
         # Then try to load staticfiles_urls from installed apps
         app_configs = apps.get_app_configs()
@@ -126,15 +124,13 @@ class DownloaderFinder(BaseFinder):
             if staticfiles_urls:
                 self._load(
                     staticfiles_urls,
-                    ".".join([app_config.name, self.urls_attr]),
+                    '.'.join([app_config.name, self.urls_attr]),
                 )
         super(DownloaderFinder, self).__init__(*args, **kwargs)
 
     def _load(self, staticfiles_urls, variable_name):
         if not isinstance(staticfiles_urls, dict):
-            raise ImproperlyConfigured(
-                'Value of "{}" is not a dict.'.format(variable_name)
-            )
+            raise ImproperlyConfigured('Value of "{}" is not a dict.'.format(variable_name))
         for path, url in staticfiles_urls.items():
             if isinstance(url, (list, tuple)):
                 try:
@@ -142,14 +138,10 @@ class DownloaderFinder(BaseFinder):
                 except ValueError:
                     raise ImproperlyConfigured(
                         'Values of "{}" must be string '
-                        "urls or tuples (url, algorithm, checksum).".format(
-                            variable_name
-                        )
+                        'urls or tuples (url, algorithm, checksum).'.format(variable_name)
                     )
                 if algorithm not in hashlib.algorithms_available:
-                    raise ImproperlyConfigured(
-                        'The algorythm "{}" is not available.'.format(algorithm)
-                    )
+                    raise ImproperlyConfigured('The algorythm "{}" is not available.'.format(algorithm))
             else:
                 algorithm, checksum = None, None
             if path not in self.firsts:
